@@ -107,7 +107,7 @@ _warning (const char *format, ...)
       char *message = g_strdup_vprintf (text, args);
       char *newline = "\n";
 
-      g_logv ("Wmakerconf", G_LOG_LEVEL_WARNING, text, args);
+      g_log ("Wmakerconf", G_LOG_LEVEL_WARNING, message);
       Free (text);
       gtk_text_insert (GTK_TEXT (log_text), NULL, NULL, NULL, message, -1);
       Free (message);
