@@ -481,8 +481,9 @@ wwwpage (GtkWidget *w, gpointer ptr)
 {
 #ifdef NETSCAPE
    char *www = (char *) ptr;
-   char *tmp = g_strdup_printf (NETSCAPE " -remote 'openURL(%s,  new-window)' || "
-				NETSCAPE " %s &", www, www);
+   char *tmp = g_strdup_printf (
+       NETSCAPE " -remote 'openURL(%s,  new-window)' > /dev/null 2>&1 || "
+       NETSCAPE " '%s' &", www, www);
    system (tmp);
    Free (tmp);
 #endif
