@@ -101,14 +101,75 @@ Calloc (size_t n, size_t size)
    return ptr;
 }
 
+char *
+get_tempdir (void)
+{
+   static char * tempdir;
+   tempdir = getenv ("TMPDIR");
+   if (tempdir && *tempdir)
+      return g_strdup (tempdir);
+   else
+      return g_strdup ("/tmp");
+}
+
+char *
+make_temporary_directory (void)
+{
+#ifdef HAVE_MKDTEMP
+   static char *name = NULL;
+   static char *tmpdir;
+
+   Free (name);
+   tmpdir = get_tempdir ();
+   name = g_strconcat (tmpdir, "/wmdirXXXXXX", NULL);
+   Free (tmpdir);
+
+   if (!mkdtemp (name))
+   {
+      Free (name);
+      name = NULL;
+   }
+      
+#else /* not HAVE_MKDTEMP */
+   char *name = tmpnam (NULL);
+   if (name)
+      make_directory (name);
+     
+#endif /* not HAVE_MKDTEMP */
+   
+   if (name)
+      return name;
+   else
+   {
+      make_directory ("/tmp/wmakerconf.dir");
+      return "/tmp/wmakerconf.dir";
+   }
+}
+
 char *
 get_temporary_file_name (void)
 {
-#ifdef HAVE_TEMPNAM
-   char *name = (char *) tempnam (NULL, "wmcnf");
-#else  /* not HAVE_TEMPNAM */
+#ifdef HAVE_MKSTEMP
+   static char *name = NULL;
+   static char *tmpdir;
+   int fd;
+   
+   Free (name);
+   tmpdir = get_tempdir ();
+   name = g_strconcat (tmpdir, "/wmcnfXXXXXX", NULL);
+   Free (tmpdir);
+   
+   if ((fd = mkstemp (name)) >= 0)
+      close (fd);
+   else
+   {
+      Free (name);
+      name = NULL;
+   }
+
+#else  /* not HAVE_MKSTEMP */
    char *name = tmpnam (NULL);
-#endif /* not HAVE_TEMPNAM */
+#endif /* not HAVE_MKSTEMP */
 
    if (name)
       return name;
@@ -597,7 +658,7 @@ preview_name (const char *name)
    return path;
 }
 
-proplist_t *
+proplist_t
 read_proplist (const char *filename)
 /*
  *  Call Alfredo's PropList parser ...
