@@ -34,7 +34,7 @@
 #include <ctype.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <proplist.h>
+#include "proplist_t.h"
 
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
@@ -132,9 +132,9 @@ static bool_t	debian_menu = FALSE;
 *******************************************************************************/
 
 static GtkCTreeNode *
-build_tree (GtkCTreeNode *parent, GtkCTreeNode *sibling, proplist_t *menu);
+build_tree (GtkCTreeNode *parent, GtkCTreeNode *sibling, proplist_t menu);
 static GtkWidget *
-real_rootmenu (GtkTooltips *tooltips, proplist_t *menu);
+real_rootmenu (GtkTooltips *tooltips, proplist_t menu);
 static void
 item_destructor (gpointer data);
 static item_t *
@@ -224,7 +224,7 @@ tree_moved (GtkCTree *ctree, GtkCTreeNode *node, GtkCTreeNode *new_parent,
 	    GtkCTreeNode *new_sibling);
 static void
 row_moved (GtkWidget *clist, gint source_row, gint dest_row);
-static proplist_t *
+static proplist_t
 convert_to_proplist (const char *filename);
 static void
 convert_current_menu (GtkWidget *button, gpointer data);
@@ -234,7 +234,7 @@ static void
 use_wmaker_menu (GtkWidget *button, gpointer data);
 static void
 convert_wmaker_menu (GtkWidget *button, gpointer data);
-static proplist_t *
+static proplist_t
 save_node (GNode *gnode);
 
 /*******************************************************************************
@@ -247,9 +247,9 @@ GtkWidget *
 rootmenu_dialog (GtkWidget *page, GtkTooltips *tooltips)
 {
    char       *filename = get_gnustep_path ("Defaults/WMRootMenu");
-   proplist_t *menu 	= read_proplist (filename);
+   proplist_t menu 	= read_proplist (filename);
 
-   if (!menu || PLIsString (menu))
+   if (!menu || WMIsPLString (menu))
    {
       GtkWidget *vbox = gtk_vbox_new (FALSE, 3);
 
@@ -278,7 +278,7 @@ rootmenu_dialog (GtkWidget *page, GtkTooltips *tooltips)
 				    GTK_BUTTONBOX_SPREAD);
 	 gtk_box_pack_start (GTK_BOX (vbox), bbox, FALSE, TRUE, 5);
 
-	 if (menu && PLIsString (menu))
+	 if (menu && WMIsPLString (menu))
 	 {
 	    button = gtk_button_new_with_label (_("Convert current menu"));
 	    gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, TRUE, 5);
@@ -287,7 +287,7 @@ rootmenu_dialog (GtkWidget *page, GtkTooltips *tooltips)
 				  NULL);
 	    gtk_signal_connect (GTK_OBJECT (button), "clicked",
 				GTK_SIGNAL_FUNC (convert_current_menu),
-				g_strdup (PLGetString (menu)));
+				g_strdup (WMGetFromPLString (menu)));
 	 }
 
 	 button = gtk_button_new_with_label (_("Start with empty menu"));
@@ -315,7 +315,7 @@ rootmenu_dialog (GtkWidget *page, GtkTooltips *tooltips)
       
       gtk_widget_show_all (page);
       if (menu)
-	 PLRelease (menu);
+	 WMReleasePropList (menu);
       
       {
 	 GtkWidget *vbox = gtk_vbox_new (FALSE, 5);
@@ -351,27 +351,26 @@ save_rootmenu (void)
       GNode	   *node = gtk_ctree_export_to_gnode (GTK_CTREE (menu_tree),
 						      NULL, NULL, root, itemcopy,
 						      NULL);
-      proplist_t   *menu = save_node (node);
+      proplist_t   menu = save_node (node);
       char	   *filename = get_gnustep_path ("Defaults/WMRootMenu");
 
       g_node_traverse (node, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
 		       node_freeitem, NULL);
       g_node_destroy (node);
 
-      menu = PLSetFilename (menu, PLMakeString (filename));
-      if (PLSave (menu, YES))
+      if (WMWritePropListToFile (menu, filename, YES))
       {
 	 menu_changed = NO;
 	 message (_("Window Maker root menu file '%s' saved."), filename);
 	 Free (filename);
-	 PLRelease (menu);
+	 WMReleasePropList (menu);
       }
       else
       {
 	 dialog_popup (DIALOG_ERROR, NULL, NULL,
 		       _("Can't write to menu file\n`%s'"), filename);
 	 Free (filename);
-	 PLRelease (menu);
+	 WMReleasePropList (menu);
 	 
 	 return FALSE;			/* ERROR */
       }
@@ -385,14 +384,14 @@ save_rootmenu (void)
   
 *******************************************************************************/
 
-static proplist_t *
+static proplist_t
 save_node (GNode *gnode)
 {
    item_t     *item  = gnode->data;
-   proplist_t *pnode = PLMakeArrayFromElements (NULL);
+   proplist_t pnode = WMCreatePLArray (NULL);
    unsigned   pos    = 0;
 
-   PLInsertArrayElement (pnode, PLMakeString (item->name), pos++);
+   WMInsertInPLArray (pnode, pos++, WMCreatePLString (item->name));
    if (item->action == WM_MENU)
    {
       GNode *gchild;
@@ -400,13 +399,13 @@ save_node (GNode *gnode)
       if (gnode->children || gnode->parent == NULL)
 	 for (gchild = gnode->children; gchild; gchild = gchild->next)
 	 {
-	    proplist_t *pchild = save_node (gchild);
+	    proplist_t pchild = save_node (gchild);
 	    if (pchild)
-	       PLInsertArrayElement (pnode, pchild, pos++);
+	       WMInsertInPLArray (pnode, pos++, pchild);
 	 }
       else
       {
-	 PLRelease (pnode);
+	 WMReleasePropList (pnode);
 	 return NULL;			/* don't export empty dir's */
       }
    }
@@ -418,39 +417,39 @@ save_node (GNode *gnode)
 	 if (item->shortcut && strlen (item->shortcut)
 	     && !strcaseeq (item->shortcut, "none"))
 	 {
-	    PLInsertArrayElement (pnode, PLMakeString ("SHORTCUT"), pos++);
-	    PLInsertArrayElement (pnode, PLMakeString (item->shortcut), pos++);
+	    WMInsertInPLArray (pnode, pos++, WMCreatePLString ("SHORTCUT"));
+	    WMInsertInPLArray (pnode, pos++, WMCreatePLString (item->shortcut));
 	 }
       }
-      PLInsertArrayElement (pnode, PLMakeString ((char *) cmd_id [item->action]),
-			    pos++);
+      WMInsertInPLArray (pnode, pos++,
+		         WMCreatePLString ((char *) cmd_id [item->action]));
       if (!item->arg)
 	 item->arg = g_strdup ("");
       if (item->action == WM_EXEC || item->action == WM_SHEXEC
 	  || item->action == WM_INCLUDE || item->action == WM_OPEN_MENU)
-	 PLInsertArrayElement (pnode, PLMakeString (item->arg), pos++);
+	 WMInsertInPLArray (pnode, pos++, WMCreatePLString (item->arg));
       else if (item->action == WM_PIPE)
       {
 	 char *tmp = g_strdup_printf ("| %s", item->arg);
-	 PLInsertArrayElement (pnode, PLMakeString (tmp), pos++);
+	 WMInsertInPLArray (pnode, pos++, WMCreatePLString (tmp));
 	 Free (tmp);
       }
       else if (item->action == WM_EXIT || item->action == WM_SHUTDOWN)
       {
 	 if (streq (item->arg, "QUICK"))
-	    PLInsertArrayElement (pnode, PLMakeString (item->arg), pos++);
+	    WMInsertInPLArray (pnode, pos++, WMCreatePLString (item->arg));
       }
       else if (item->action == WM_RESTART)
       {
 	 if (strlen (item->arg))
-	    PLInsertArrayElement (pnode, PLMakeString (item->arg), pos++);
+	    WMInsertInPLArray (pnode, pos++, WMCreatePLString (item->arg));
       }
    }
    return pnode;
 }
 
 static GtkWidget *
-real_rootmenu (GtkTooltips *tooltips, proplist_t *menu)
+real_rootmenu (GtkTooltips *tooltips, proplist_t menu)
 {
    GtkWidget	*scrolled;
    GtkWidget	*ctree;
@@ -832,7 +831,7 @@ real_rootmenu (GtkTooltips *tooltips, proplist_t *menu)
    if (menu)
    {
       root = build_tree (NULL, NULL, menu);
-      PLRelease (menu);
+      WMReleasePropList (menu);
    }
    else
    {
@@ -927,7 +926,7 @@ init_action_commands (void)
 }
 
 static GtkCTreeNode *
-build_tree (GtkCTreeNode *parent, GtkCTreeNode *sibling, proplist_t *menu)
+build_tree (GtkCTreeNode *parent, GtkCTreeNode *sibling, proplist_t menu)
 /*
  *  Recursively build a menu tree using the 'ctree' widget.
  *  If 'parent' != NULL insert node as a new child of 'parent'.
@@ -940,20 +939,20 @@ build_tree (GtkCTreeNode *parent, GtkCTreeNode *sibling, proplist_t *menu)
  */
 {
    char		*text;
-   proplist_t	*pl;
+   proplist_t	pl;
    unsigned	n;
    GtkCTreeNode *node;
 	 
-   if (!PLIsArray (menu) || (n = PLGetNumberOfElements (menu)) < 1)
+   if (!WMIsPLArray (menu) || (n = WMGetPropListItemCount (menu)) < 1)
       return NULL;			/* ERROR */
    
-   pl = PLGetArrayElement (menu, 0);
-   if (!PLIsString (pl))
+   pl = WMGetFromPLArray (menu, 0);
+   if (!WMIsPLString (pl))
       return NULL;			/* ERROR */
-   text = PLGetString (pl);
+   text = WMGetFromPLString (pl);
    
-   pl = PLGetArrayElement (menu, 1);
-   if (n == 1 || PLIsArray (pl))	/* submenu */
+   pl = WMGetFromPLArray (menu, 1);
+   if (n == 1 || WMIsPLArray (pl))	/* submenu */
    {
       unsigned k;
       item_t   *item = item_constructor (text, WM_MENU, NULL, NULL);
@@ -967,8 +966,8 @@ build_tree (GtkCTreeNode *parent, GtkCTreeNode *sibling, proplist_t *menu)
       
       for (k = 1; k < n; k++)
       {
-	 pl = PLGetArrayElement (menu, k);
-	 if (PLIsArray (pl))		/* submenu */
+	 pl = WMGetFromPLArray (menu, k);
+	 if (WMIsPLArray (pl))		/* submenu */
 	    build_tree (node, NULL, pl);
 	 else
 	    return NULL;		/* ERROR */
@@ -980,17 +979,17 @@ build_tree (GtkCTreeNode *parent, GtkCTreeNode *sibling, proplist_t *menu)
       char	*action;
       int	an;
       
-      action  = PLGetString (pl);
+      action  = WMGetFromPLString (pl);
 	 
       if (streq (action, "SHORTCUT"))
       {
 	 if (n >= 4)			/* name SHORTCUT shortcutdef COMMAND */
 	 {
-	    pl = PLGetArrayElement (menu, 2);
-	    new->shortcut = g_strdup (PLGetString (pl));
-	    pl = PLGetArrayElement (menu, 3);
+	    pl = WMGetFromPLArray (menu, 2);
+	    new->shortcut = g_strdup (WMGetFromPLString (pl));
+	    pl = WMGetFromPLArray (menu, 3);
 	    if (n >= 5)			/* ... COMMAND OPTIONS */
-	       new->arg = g_strdup (PLGetString (PLGetArrayElement (menu, 4)));
+	       new->arg = g_strdup (WMGetFromPLString (WMGetFromPLArray (menu, 4)));
 	 }
 	 else
 	 {
@@ -999,9 +998,9 @@ build_tree (GtkCTreeNode *parent, GtkCTreeNode *sibling, proplist_t *menu)
 	 }
       }
       else if (n >= 3)		/* ... COMMAND OPTIONS */
-	 new->arg = g_strdup (PLGetString (PLGetArrayElement (menu, 2)));
+	 new->arg = g_strdup (WMGetFromPLString (WMGetFromPLArray (menu, 2)));
 
-      action = PLGetString (pl);
+      action = WMGetFromPLString (pl);
 	 
       new->action = WM_MENU;
       for (an = 0; an < WM_LAST; an++)
@@ -1799,7 +1798,7 @@ open_filebrowser (GtkWidget *button, gpointer data)
 	 char *filename = gtk_entry_get_text (GTK_ENTRY (include_file_entry));
 
 	 if (streq (filename, ""))
-	    gtk_file_selection_set_filename (fs, WMAKERDATADIR "/");
+	    gtk_file_selection_set_filename (fs, WMAKERDIR "/");
 	 else
 	    gtk_file_selection_set_filename (fs, filename);
       }
@@ -1839,7 +1838,7 @@ set_entry_text (GtkWidget *entry, gpointer data)
 static void
 import_menu (GtkWidget *widget, gpointer data)
 {
-   proplist_t	*menu;
+   proplist_t	menu;
    GtkCTreeNode *node = (GTK_CLIST (menu_tree)->selection)->data;
    GtkCTreeNode *new;
    item_t	*item_old = gtk_ctree_node_get_row_data (GTK_CTREE (menu_tree),
@@ -1860,11 +1859,11 @@ import_menu (GtkWidget *widget, gpointer data)
       filename = get_gnustep_path (tmp);
       Free (tmp);
       file = fopen (filename, "r");
-      if (!file)			/* check WMAKERDATADIR */
+      if (!file)			/* check WMAKERDIR */
       {
 	 Free (filename);
 	 tmp = expand_tilde (data ? data : item_old->arg);
-	 filename = g_strdup_printf ("%s/%s", WMAKERDATADIR, tmp);
+	 filename = g_strdup_printf ("%s/%s", WMAKERDIR, tmp);
 	 Free (tmp);
 	 /* error checking is done a few lines below */
       }
@@ -1883,7 +1882,7 @@ import_menu (GtkWidget *widget, gpointer data)
    gtk_clist_freeze (GTK_CLIST (menu_tree));
    new = build_tree (GTK_CTREE_ROW (node)->parent, node, menu);
 
-   PLRelease (menu);
+   WMReleasePropList (menu);
 
    item_new = gtk_ctree_node_get_row_data (GTK_CTREE (menu_tree), new);
    Free (item_new->name);
@@ -2079,7 +2078,7 @@ set_default_menu (GtkWidget *menuitem, gpointer data)
    gtk_object_set_user_data (GTK_OBJECT (menuitem),
 			     (gpointer) cmd_name [WM_INCLUDE]);
    set_command (menuitem, NULL);
-   gtk_entry_set_text (GTK_ENTRY (include_file_entry), WMAKERDATADIR "/menu");
+   gtk_entry_set_text (GTK_ENTRY (include_file_entry), WMAKERDIR "/menu");
    gtk_entry_set_text (GTK_ENTRY (itemlabel_entry), "Default menu");
    toggle_save (menu_changed = YES, NULL);
 }
@@ -2258,28 +2257,44 @@ row_moved (GtkWidget *clist, gint source_row, gint dest_row)
    dir_list_to_item (clist, NULL);
 }
 
-static proplist_t *
-convert_to_proplist (const char *filename)
+static proplist_t
+convert_to_proplist (const char *cfilename)
 {
-   proplist_t	*menu;
-   int		c;
-   FILE		*file     = fopen (filename, "r");
+   proplist_t	menu;
+   int		c         = 0;
+   char         *filename = g_strdup (cfilename);
    char		*tmp_name = NULL;
-      
+   FILE		*file     = NULL;
+   
    /*
     *  Check if file is already in proplist format
     */
-   if (!file)
+   if (filename[0] == '/')
+      file = fopen (filename, "r");
+   else /* not an absolute path; look for file in the usual places */
    {
-      dialog_popup (DIALOG_ERROR, NULL, NULL,
-		    _("Can't read file '%s'"), filename);
-      return NULL;			
+      int i;
+      char * prefixes[2];
+      prefixes[0] = get_gnustep_path ("Library/WindowMaker/");
+      prefixes[1] = g_strdup ("/etc/X11/WindowMaker/");
+
+      for (i = 0; i < 2 && !file; i++)
+      {
+         Free (filename);
+	 filename = g_strconcat (prefixes[i], cfilename, NULL);
+	 file = fopen (filename, "r");
+      }
+      Free (prefixes[0]);
+      Free (prefixes[1]);
    }
-
-   while ((c = fgetc (file)) != EOF && isspace (c))
-      ;
-   fclose (file);
-
+   
+   if (file)
+   {
+      while ((c = fgetc (file)) != EOF && isspace (c))
+         ;
+      fclose (file);
+   }
+   
    if (c == '(')
       menu = read_proplist (filename);
    else
@@ -2292,6 +2307,7 @@ convert_to_proplist (const char *filename)
       command  = g_strdup_printf ("%s/wm-oldmenu2new.sh %s %s", PKGDATADIR,
 				  filename, tmp_name);
 
+      Free (filename);
       if (shell_command (command, txt))
       {
 	 Free (command);
@@ -2303,13 +2319,13 @@ convert_to_proplist (const char *filename)
       menu = read_proplist (tmp_name);
    }
    
-   if (!menu || !PLIsArray (menu))
+   if (!menu || !WMIsPLArray (menu))
    {
       dialog_popup (DIALOG_ERROR, NULL, NULL,
 		    _("Can't parse generated menu file\n`%s'.\n"
 		      "Please check syntax of this file."), tmp_name);
       if (menu)
-	 PLRelease (menu);
+	 WMReleasePropList (menu);
       
       return NULL;			/* ERROR */
    }
@@ -2383,7 +2399,7 @@ use_wmaker_menu (GtkWidget *button, gpointer data)
 				 GTK_SIGNAL_FUNC (gtk_widget_destroy),
 				 GTK_OBJECT (filesel));
 
-      gtk_file_selection_set_filename (fs, WMAKERDATADIR "/");
+      gtk_file_selection_set_filename (fs, WMAKERDIR "/");
       gtk_file_selection_complete (fs, "*menu*");
    }
 
