@@ -126,6 +126,10 @@ init_option_menu (gpointer data, gpointer user_data);
 static void
 appearance_container (proplist_t type, proplist_t thispanel,
 		      GList **options, GtkWidget *box);
+static int
+compare_fn (const void * p1, const void * p2);
+
+typedef struct { char * name; char * intlname; } names_t;
 
 /*****************************************************************************
 
@@ -305,10 +309,32 @@ root_window (const char *conffile, const node *sections,
     *  Section information is extracted from config file 'WMWmakerconf'. 
     */
    {
-      proplist_t tab = WMGetPLDictionaryKeys (panel);
-      unsigned	 n;
-      
-      for (n = 0; n < WMGetPropListItemCount (tab); n++)
+      proplist_t  tab_orig = WMGetPLDictionaryKeys (panel);
+      proplist_t  tab      = WMCreatePLArray (NULL);
+      names_t    *tab_s;
+      unsigned	  n;
+      int         size     = WMGetPropListItemCount (tab_orig);
+
+      /* Sort the tabs alphabetically by the current translation.
+       * (OK, technically this isn't quite correct since the compare
+       * function is strcmp and the text ought to be UTF-8...)
+       * Unfortunately libWINGs provides no convenient way to do this. */
+      tab_s = malloc (size * sizeof (names_t));
+      for (n = 0; n < size; n++) {
+        proplist_t thispanel = WMGetFromPLArray (tab_orig, n);
+        proplist_t entry     = WMGetFromPLDictionary (panel, thispanel);
+        proplist_t info      = WMGetFromPLDictionary (entry, plinfo);
+
+        tab_s[n].name        = WMGetFromPLString (thispanel);
+        tab_s[n].intlname    = D_(WMGetFromPLString(info));
+      }
+      qsort (tab_s, size, sizeof (names_t), compare_fn);
+      for (n = 0; n < size; n++)
+        WMAddToPLArray (tab, WMCreatePLString (tab_s[n].name));
+      free (tab_s);
+      WMReleasePropList (tab_orig);
+
+      for (n = 0; n < size; n++)
       {
 	 proplist_t thispanel = WMGetFromPLArray (tab, n);
 	 proplist_t entry     = WMGetFromPLDictionary (panel, thispanel);
@@ -1072,6 +1098,10 @@ save_config_file (GtkWidget *widget, gpointer ptr)
   
 *****************************************************************************/
 
+static int
+compare_fn (const void *p1, const void *p2)
+{ return strcmp(((names_t *)p1)->intlname, ((names_t *)p2)->intlname); }
+
 static void
 appearance_container (proplist_t type, proplist_t thispanel,
 		      GList **options, GtkWidget *box)
